@@ -1,4 +1,5 @@
 #' Topic
 #'
 #' This macro is \unknown{}. This one is \known{}.
-testUnknownMacro <- function() {}
+testUnknownMacro <- function() {
+}
